@@ -90,7 +90,7 @@ private:
     StringCache &m_cache;
     std::function<QByteArray()> m_fetchAnotherLine;
 
-    VCardLine *m_vCardLine;
+    VCardLine *m_vCardLine = nullptr;
     QByteArray m_encoding;
     QByteArray m_charset;
 };
@@ -183,9 +183,7 @@ void VCardLineParser::parseLine(const QByteArray& currentLine, KContacts::VCardL
                 start = pos + 1;
             }
             // fall-through intended
-#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
-        Q_FALLTHROUGH();
-#endif
+            Q_FALLTHROUGH();
         case StateAfterParamValue:
             if (ch == ';') {
                 state = StateParamKey;
@@ -276,7 +274,7 @@ VCard::List VCardParser::parseVCards(const QByteArray &text)
     bool inVCard = false;
 
     StringCache cache;
-    for (; lineEnd != -1; lineStart = lineEnd + 1, lineEnd = text.indexOf('\n', lineStart)) {
+    for (; lineStart != text.size() + 1; lineStart = lineEnd + 1, lineEnd = (text.indexOf('\n', lineStart) == -1) ? text.size() : text.indexOf('\n', lineStart)) {
         QByteArray cur = text.mid(lineStart, lineEnd - lineStart);
         // remove the trailing \r, left from \r\n
         if (cur.endsWith('\r')) {
